@@ -49,6 +49,9 @@ static R_CallMethodDef CallEntries[] = {
     {"RGDAL_GetXSize", (DL_FUNC) &RGDAL_GetXSize, 1},
     {"RGDAL_GetGeoTransform", (DL_FUNC) &RGDAL_GetGeoTransform, 1},
     {"RGDAL_GetRasterBlockSize", (DL_FUNC) &RGDAL_GetRasterBlockSize, 1},
+    {"RGDAL_CPLGetConfigOption", (DL_FUNC) &RGDAL_CPLGetConfigOption, 1},
+    {"RGDAL_CPLSetConfigOption", (DL_FUNC) &RGDAL_CPLSetConfigOption, 2},
+    {"RGDAL_CPL_RECODE_ICONV", (DL_FUNC) &RGDAL_CPL_RECODE_ICONV, 0},
     {"PROJcopyEPSG", (DL_FUNC) &PROJcopyEPSG, 1},
     {"ogrInfo", (DL_FUNC) &ogrInfo, 2},
     {"R_OGR_types", (DL_FUNC) &R_OGR_types, 2},
