@@ -297,6 +297,8 @@ SEXP transform(SEXP fromargs, SEXP toargs, SEXP npts, SEXP x, SEXP y) {
 SEXP checkCRSArgs(SEXP args) {
 	SEXP res;
 	projPJ pj;
+        char cbuf[512], cbuf1[512], c;
+        int i, k;
 	PROTECT(res = NEW_LIST(2));
 	SET_VECTOR_ELT(res, 0, NEW_LOGICAL(1));
 	SET_VECTOR_ELT(res, 1, NEW_CHARACTER(1));
@@ -311,8 +313,18 @@ SEXP checkCRSArgs(SEXP args) {
 		return(res);
 	}
 
-	SET_STRING_ELT(VECTOR_ELT(res, 1), 0, 
-		COPY_TO_USER_STRING(pj_get_def(pj, 0)));
+        strcpy(cbuf, pj_get_def(pj, 0));
+        c = cbuf[0];
+        if (isspace(c)) {
+            k = (int) strlen(cbuf);
+            for (i=0; i<(k-1); i++) cbuf1[i] = cbuf[i+1];
+            cbuf1[(k-1)] = '\0';
+	    SET_STRING_ELT(VECTOR_ELT(res, 1), 0, 
+		COPY_TO_USER_STRING(cbuf1));
+        } else {
+	    SET_STRING_ELT(VECTOR_ELT(res, 1), 0, 
+		COPY_TO_USER_STRING(cbuf));
+        }
 	
 	LOGICAL_POINTER(VECTOR_ELT(res, 0))[0] = TRUE;
 	
